@@ -315,32 +315,44 @@ class Parameters:
         self.id = id
 
     def get(self):
-        """Returns list of nodes with parameters supported by ``Parameters`` node."""
+        """Returns list of nodes with parameters and strategies supported by ``Parameters`` node."""
         return self.api.get('parameters/nodes')
 
     def set(
             self,
             node_type: str,
-            parameters: Dict[str, str],
+            parameters: Union[Dict[str, str], List[Dict[str, str]]],
+            strategies: Optional[List[int]] = None,
             declare_unsync: bool = True,
             hard_update: bool = True,
     ) -> Optional[List[str]]:
         """
-        Sets `node_type` parameters for the Parameters node.
+        Sets `node_type` parameters and strategies for the Parameters node.
+
+        If `parameters` is the list of dictionaries with parameters then
+        /configure-array endpoint is used otherwise /configure.
 
         :param node_type: node type which parameters needs to be set
         :param parameters: node type parameters
+        :param strategies: node type strategies
         :param declare_unsync: reset status of the Parameters node. True by default.
         :param hard_update: update every child node with new parameters if True, \
             otherwise reset their statuses. Works only if declare_unsync is True.\
             True by default.
         """
+
+        if strategies is None:
+            strategies = []
+
+        method = 'configure-array' if isinstance(parameters, list) else 'configure'
+
         return self.api.post(
-            'parameters/configure',
+            f'parameters/{method}',
             params={'prjUUID': self.uuid, 'obj': self.id},
             json={
                 'type': node_type,
                 'settings': parameters,
+                'strategies': strategies,
                 'declareUnsync': declare_unsync,
                 'hardUpdate': hard_update,
             },
@@ -348,14 +360,15 @@ class Parameters:
 
     def clear(self, *node_types: List[str], declare_unsync: bool = True) -> Optional[List[str]]:
         """
-        Clears parameters of `node_types` for the Parameters node.
+        Clears parameters and strategies of `node_types` for the Parameters node.
+        If `node_types` is empty it clears parameters and strategies of all nodes.
 
         :param node_types: node types which parameters needs to be cleared
         :param declare_unsync: reset status of the Parameters node
         """
         return self.api.post(
             'parameters/clear',
-            params={'prjUUID': self.uuid, 'obj': id},
+            params={'prjUUID': self.uuid, 'obj': self.id},
             json={
                 'nodes': node_types,
                 'declareUnsync': declare_unsync,
